Feature: Use the website inspector command line app
    In order to quickly inspect a website
    I want a quick command line app to search a website

    Scenario: Monitor status of the website scraper
        When I get help for "website_inspector"
        Then the exit status should be 0
        And the banner should be present
        And there should be a one line summary of what the app does
        And the banner should include the version
        And the banner should document that this app takes options
        And the banner should document that this app's arguments are:
            |website_url        | which is required |
            |search_terms       | which is required |
        And the following options should be documented:
            |page_object        |
            |title              |
            |html               |
            |source             |
            |hyperlinks         |
            |images             |
            |image_hyperlinks   |
            |page_forms         |

    Scenario: Successfully start the website inspector
        Given I run `website_inspector http://www.google.com shop`
        Then the exit status should be 0
        And the stdout should contain "INFO -- : Website Inspector has finished running"

    Scenario: Return accurate results
        Given I run `website_inspector zappos.com shoes`
        Then the exit status should be 0
        And the stdout should contain "SEARCHING TITLE"

    Scenario: Display Error if no website urls are provided
        Given I run `website_inspector`
        Then the exit status should not be 0
        And the stderr should contain "ERROR -- : parse error: 'website_url' is required"

    Scenario: Display Error if no search terms are provided
        Given I run `website_inspector www.google.com`
        Then the exit status should not be 0
        And the stderr should contain "ERROR -- : parse error: 'search_terms' is required"

    Scenario Outline: Successfully run website inspector with any of the options
        When I run `website_inspector www.zappos.com "option"`
        Then the exit status should be 0
        And the stdout should contain "option"
        Examples:
            |option               |   stdout              |
            |--page_object        |   "PAGE"              |
            |--title              |   "TITLE"             |
            |--html               |   "HTML/XML"          |
            |--source             |   "WEBPAGE SOURCE"    |
            |--hyperlinks         |   "LINKS"             |
            |--images             |   "IMAGES"            |
            |--image_hyperlinks   |   "IMAGE URLS"        |
            |--page_forms         |   "PAGE FORMS"        |
